@@ -1,16 +1,23 @@
 # frozen_string_literal: true
+
 require 'rack/session/abstract/id'
 require 'dalli'
+require 'connection_pool'
+require 'English'
 
 module Rack
   module Session
-    class Dalli < defined?(Abstract::Persisted) ? Abstract::Persisted : Abstract::ID
-      attr_reader :pool, :mutex
+    # Rack::Session::Dalli provides memcached based session management.
+    class Dalli < Abstract::Persisted
+      attr_reader :pool
 
+      # Don't freeze this until we fix the specs/implementation
+      # rubocop:disable Style/MutableConstant
       DEFAULT_DALLI_OPTIONS = {
-        :namespace => 'rack:session',
-        :memcache_server => 'localhost:11211'
+        namespace: 'rack:session',
+        memcache_server: 'localhost:11211'
       }
+      # rubocop:enable Style/MutableConstant
 
       # Brings in a new Rack::Session::Dalli middleware with the given
       # `:memcache_server`. The server is either a hostname, or a
@@ -66,7 +73,7 @@ module Rack
       # for more information about it and its default options (which would only
       # be applicable if you supplied one of the two options, but not both).
       #
-      def initialize(app, options={})
+      def initialize(app, options = {})
         # Parent uses DEFAULT_OPTIONS to build @default_options for Rack::Session
         super
 
@@ -74,28 +81,17 @@ module Rack
         @default_ttl = ttl @default_options[:expire_after]
 
         # Normalize and validate passed options
-        cache, mserv, mopts, popts = extract_dalli_options options
+        mserv, mopts, popts = extract_dalli_options(options)
 
-        @pool =
-          if cache # caller passed a Dalli::Client or ConnectionPool instance
-            cache
-          elsif popts # caller passed ConnectionPool options
-            ConnectionPool.new(popts) { ::Dalli::Client.new(mserv, mopts) }
-          else
-            ::Dalli::Client.new(mserv, mopts)
-          end
-
-        if @pool.respond_to?(:alive!) # is a Dalli::Client
-          @mutex = Mutex.new
-
-          @pool.alive!
-        end
+        @pool = ConnectionPool.new(popts || {}) { ::Dalli::Client.new(mserv, mopts) }
       end
 
-      def get_session(env, sid)
-        with_block(env, [nil, {}]) do |dc|
-          unless sid and !sid.empty? and session = dc.get(sid)
-            old_sid, sid, session = sid, generate_sid_with(dc), {}
+      def get_session(_env, sid)
+        with_block([nil, {}]) do |dc|
+          unless sid && !sid.empty? && (session = dc.get(sid))
+            old_sid = sid
+            sid = generate_sid_with(dc)
+            session = {}
             unless dc.add(sid, session, @default_ttl)
               sid = old_sid
               redo # generate a new sid and try again
@@ -105,77 +101,72 @@ module Rack
         end
       end
 
-      def set_session(env, session_id, new_session, options)
+      def set_session(_env, session_id, new_session, options)
         return false unless session_id
 
-        with_block(env, false) do |dc|
+        with_block(false) do |dc|
           dc.set(session_id, new_session, ttl(options[:expire_after]))
           session_id
         end
       end
 
-      def destroy_session(env, session_id, options)
-        with_block(env) do |dc|
+      def destroy_session(_env, session_id, options)
+        with_block do |dc|
           dc.delete(session_id)
           generate_sid_with(dc) unless options[:drop]
         end
       end
 
-      if defined?(Abstract::Persisted)
-        def find_session(req, sid)
-          get_session req.env, sid
-        end
+      def find_session(req, sid)
+        get_session req.env, sid
+      end
 
-        def write_session(req, sid, session, options)
-          set_session req.env, sid, session, options
-        end
+      def write_session(req, sid, session, options)
+        set_session req.env, sid, session, options
+      end
 
-        def delete_session(req, sid, options)
-          destroy_session req.env, sid, options
-        end
+      def delete_session(req, sid, options)
+        destroy_session req.env, sid, options
       end
 
       private
 
       def extract_dalli_options(options)
-        return [options[:cache]] if options[:cache]
+        raise 'Rack::Session::Dalli no longer supports the :cache option.' if options[:cache]
 
         # Filter out Rack::Session-specific options and apply our defaults
-        mopts = DEFAULT_DALLI_OPTIONS.merge \
-          options.reject {|k, _| DEFAULT_OPTIONS.key? k }
+        # Filter out Rack::Session-specific options and apply our defaults
+        filtered_opts = options.reject { |k, _| DEFAULT_OPTIONS.key? k }
+        mopts = DEFAULT_DALLI_OPTIONS.merge(filtered_opts)
         mserv = mopts.delete :memcache_server
 
+        popts = {}
         if mopts[:pool_size] || mopts[:pool_timeout]
-          popts = {}
           popts[:size] = mopts.delete :pool_size if mopts[:pool_size]
           popts[:timeout] = mopts.delete :pool_timeout if mopts[:pool_timeout]
-
-          # For a connection pool, locking is handled at the pool level
-          mopts[:threadsafe] = false unless mopts.key? :threadsafe
+          mopts[:threadsafe] = true
         end
 
-        [nil, mserv, mopts, popts]
+        [mserv, mopts, popts]
       end
 
-      def generate_sid_with(dc)
-        while true
+      def generate_sid_with(client)
+        loop do
           sid = generate_sid
-          break sid unless dc.get(sid)
+          break sid unless client.get(sid)
         end
       end
 
-      def with_block(env, default=nil, &block)
-        @mutex.lock if @mutex and env['rack.multithread']
+      def with_block(default = nil, &block)
         @pool.with(&block)
       rescue ::Dalli::DalliError, Errno::ECONNREFUSED
-        raise if $!.message =~ /undefined class/
+        raise if /undefined class/.match?($ERROR_INFO.message)
+
         if $VERBOSE
           warn "#{self} is unable to find memcached server."
-          warn $!.inspect
+          warn $ERROR_INFO.inspect
         end
         default
-      ensure
-        @mutex.unlock if @mutex and @mutex.locked?
       end
 
       def ttl(expire_after)
