@@ -1,49 +1,57 @@
 # frozen_string_literal: true
+
 require_relative 'helper'
 require 'openssl'
+require 'securerandom'
 
 describe 'Dalli' do
   describe 'options parsing' do
-    it 'handle deprecated options' do
-      dc = Dalli::Client.new('foo', :compression => true)
-      assert dc.instance_variable_get(:@options)[:compress]
-      refute dc.instance_variable_get(:@options)[:compression]
-    end
-
     it 'not warn about valid options' do
-      dc = Dalli::Client.new('foo', :compress => true)
+      dc = Dalli::Client.new('foo', compress: true)
       # Rails.logger.expects :warn
       assert dc.instance_variable_get(:@options)[:compress]
     end
 
     it 'raises error with invalid expires_in' do
-      bad_data = [{:bad => 'expires in data'}, Hash, [1,2,3]]
+      bad_data = [{ bad: 'expires in data' }, Hash, [1, 2, 3]]
       bad_data.each do |bad|
         assert_raises ArgumentError do
-          Dalli::Client.new('foo', {:expires_in => bad})
+          Dalli::Client.new('foo', { expires_in: bad })
         end
       end
     end
 
-    it 'return string type for namespace attribute' do
-      dc = Dalli::Client.new('foo', :namespace => :wunderschoen)
-      assert_equal "wunderschoen", dc.send(:namespace)
-      dc.close
-
-      dc = Dalli::Client.new('foo', :namespace => Proc.new{:wunderschoen})
-      assert_equal "wunderschoen", dc.send(:namespace)
-      dc.close
-    end
-
     it 'raises error with invalid digest_class' do
       assert_raises ArgumentError do
-        Dalli::Client.new('foo', {:expires_in => 10, :digest_class => Object })
+        Dalli::Client.new('foo', { expires_in: 10, digest_class: Object })
+      end
+    end
+
+    it 'opens a standard TCP connection' do
+      memcached_persistent do |dc|
+        server = dc.send(:ring).servers.first
+        sock = Dalli::Socket::TCP.open(server.hostname, server.port, server, server.options)
+        assert_equal Dalli::Socket::TCP, sock.class
+
+        dc.set('abc', 123)
+        assert_equal(123, dc.get('abc'))
+      end
+    end
+
+    it 'opens a SSL TCP connection' do
+      memcached_ssl_persistent do |dc|
+        server = dc.send(:ring).servers.first
+        sock = Dalli::Socket::TCP.open(server.hostname, server.port, server, server.options)
+        assert_equal Dalli::Socket::SSLSocket, sock.class
+
+        dc.set('abc', 123)
+        assert_equal(123, dc.get('abc'))
       end
     end
   end
 
   describe 'key validation' do
-    it 'not allow blanks' do
+    it 'not allow blanks, but allows whitespace characters' do
       memcached_persistent do |dc|
         dc.set '   ', 1
         assert_equal 1, dc.get('   ')
@@ -52,7 +60,7 @@ describe 'Dalli' do
         dc.set "\n", 1
         assert_equal 1, dc.get("\n")
         assert_raises ArgumentError do
-          dc.set "", 1
+          dc.set '', 1
         end
         assert_raises ArgumentError do
           dc.set nil, 1
@@ -61,10 +69,10 @@ describe 'Dalli' do
     end
 
     it 'allow namespace to be a symbol' do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => :wunderschoen)
-        dc.set "x" * 251, 1
-        assert 1, dc.get("#{'x' * 200}:md5:#{Digest::MD5.hexdigest('x' * 251)}")
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", namespace: :wunderschoen)
+        dc.set 'x' * 251, 1
+        assert_equal(1, dc.get(('x' * 251).to_s))
       end
     end
   end
@@ -79,7 +87,7 @@ describe 'Dalli' do
     end
   end
 
-  it "default to localhost:11211" do
+  it 'default to localhost:11211' do
     dc = Dalli::Client.new
     ring = dc.send(:ring)
     s1 = ring.servers.first.hostname
@@ -102,36 +110,36 @@ describe 'Dalli' do
     assert_equal s2, s3
   end
 
-  it "accept comma separated string" do
-    dc = Dalli::Client.new("server1.example.com:11211,server2.example.com:11211")
+  it 'accept comma separated string' do
+    dc = Dalli::Client.new('server1.example.com:11211,server2.example.com:11211')
     ring = dc.send(:ring)
     assert_equal 2, ring.servers.size
-    s1,s2 = ring.servers.map(&:hostname)
-    assert_equal "server1.example.com", s1
-    assert_equal "server2.example.com", s2
+    s1, s2 = ring.servers.map(&:hostname)
+    assert_equal 'server1.example.com', s1
+    assert_equal 'server2.example.com', s2
   end
 
-  it "accept array of servers" do
-    dc = Dalli::Client.new(["server1.example.com:11211","server2.example.com:11211"])
+  it 'accept array of servers' do
+    dc = Dalli::Client.new(['server1.example.com:11211', 'server2.example.com:11211'])
     ring = dc.send(:ring)
     assert_equal 2, ring.servers.size
-    s1,s2 = ring.servers.map(&:hostname)
-    assert_equal "server1.example.com", s1
-    assert_equal "server2.example.com", s2
+    s1, s2 = ring.servers.map(&:hostname)
+    assert_equal 'server1.example.com', s1
+    assert_equal 'server2.example.com', s2
+  end
+
+  it 'raises error when servers is a Hash' do
+    assert_raises ArgumentError do
+      Dalli::Client.new({ hosts: 'server1.example.com' })
+    end
   end
 
   describe 'using a live server' do
-
-    it "support get/set" do
+    it 'support get/set' do
       memcached_persistent do |dc|
         dc.flush
 
-        val1 = "1234567890"*105000
-        with_nil_logger do
-          assert_equal false, dc.set('a', val1)
-        end
-
-        val1 = "1234567890"*100000
+        val1 = '1234567890' * 999_999
         dc.set('a', val1)
         val2 = dc.get('a')
         assert_equal val1, val2
@@ -164,17 +172,17 @@ describe 'Dalli' do
       end
     end
 
-    it "support stats" do
+    it 'support stats' do
       memcached_persistent do |dc|
         # make sure that get_hits would not equal 0
-        dc.set(:a, "1234567890"*100000)
+        dc.set(:a, '1234567890' * 100_000)
         dc.get(:a)
 
         stats = dc.stats
         servers = stats.keys
         assert(servers.any? do |s|
-          stats[s]["get_hits"].to_i != 0
-        end, "general stats failed")
+          stats[s]['get_hits'].to_i != 0
+        end, 'general stats failed')
 
         stats_items = dc.stats(:items)
         servers = stats_items.keys
@@ -182,15 +190,13 @@ describe 'Dalli' do
           stats_items[s].keys.any? do |key|
             key =~ /items:[0-9]+:number/
           end
-        end, "stats items failed")
+        end, 'stats items failed')
 
         stats_slabs = dc.stats(:slabs)
         servers = stats_slabs.keys
         assert(servers.all? do |s|
-          stats_slabs[s].keys.any? do |key|
-            key == "active_slabs"
-          end
-        end, "stats slabs failed")
+          stats_slabs[s].keys.any?('active_slabs')
+        end, 'stats slabs failed')
 
         # reset_stats test
         results = dc.reset_stats
@@ -200,12 +206,12 @@ describe 'Dalli' do
 
         # check if reset was performed
         servers.each do |s|
-          assert_equal 0, dc.stats[s]["get_hits"].to_i
+          assert_equal 0, dc.stats[s]['get_hits'].to_i
         end
       end
     end
 
-    it "support the fetch operation" do
+    it 'support the fetch operation' do
       memcached_persistent do |dc|
         dc.flush
 
@@ -216,7 +222,7 @@ describe 'Dalli' do
           expected
         end
         assert_equal expected, value
-        assert_equal true, executed
+        assert executed
 
         executed = false
         value = dc.fetch('fetch_key') do
@@ -224,47 +230,50 @@ describe 'Dalli' do
           expected
         end
         assert_equal expected, value
-        assert_equal false, executed
+        refute executed
       end
     end
 
-    it "support the fetch operation with falsey values" do
+    it 'support the fetch operation with falsey values' do
       memcached_persistent do |dc|
         dc.flush
 
-        dc.set("fetch_key", false)
-        res = dc.fetch("fetch_key") { flunk "fetch block called" }
-        assert_equal false, res
+        dc.set('fetch_key', false)
+        res = dc.fetch('fetch_key') { flunk 'fetch block called' }
+        refute res
       end
     end
 
-    it "support the fetch operation with nil values when cache_nils: true" do
-      memcached_persistent(21345, cache_nils: true) do |dc|
+    it 'support the fetch operation with nil values when cache_nils: true' do
+      memcached_persistent(21_345, '', cache_nils: true) do |dc|
         dc.flush
 
-        dc.set("fetch_key", nil)
-        res = dc.fetch("fetch_key") { flunk "fetch block called" }
+        dc.set('fetch_key', nil)
+        res = dc.fetch('fetch_key') { flunk 'fetch block called' }
         assert_nil res
       end
 
-      memcached_persistent(21345, cache_nils: false) do |dc|
+      memcached_persistent(21_345, '', cache_nils: false) do |dc|
         dc.flush
-        dc.set("fetch_key", nil)
+        dc.set('fetch_key', nil)
         executed = false
-        res = dc.fetch("fetch_key") { executed = true; 'bar' }
+        res = dc.fetch('fetch_key') do
+          executed = true
+          'bar'
+        end
         assert_equal 'bar', res
-        assert_equal true, executed
+        assert executed
       end
     end
 
-    it "support the cas operation" do
+    it 'support the cas operation' do
       memcached_persistent do |dc|
         dc.flush
 
         expected = { 'blah' => 'blerg!' }
 
-        resp = dc.cas('cas_key') do |value|
-          fail('Value it not exist')
+        resp = dc.cas('cas_key') do |_value|
+          raise('Value it not exist')
         end
         assert_nil resp
 
@@ -281,7 +290,7 @@ describe 'Dalli' do
       end
     end
 
-    it "support the cas! operation" do
+    it 'support the cas! operation' do
       memcached_persistent do |dc|
         dc.flush
 
@@ -297,27 +306,27 @@ describe 'Dalli' do
       end
     end
 
-    it "support multi-get" do
+    it 'supports multi-get' do
       memcached_persistent do |dc|
         dc.close
         dc.flush
-        resp = dc.get_multi(%w(a b c d e f))
-        assert_equal({}, resp)
+        resp = dc.get_multi(%w[a b c d e f])
+        assert_empty(resp)
 
         dc.set('a', 'foo')
         dc.set('b', 123)
-        dc.set('c', %w(a b c))
+        dc.set('c', %w[a b c])
         # Invocation without block
-        resp = dc.get_multi(%w(a b c d e f))
-        expected_resp = { 'a' => 'foo', 'b' => 123, 'c' => %w(a b c) }
+        resp = dc.get_multi(%w[a b c d e f])
+        expected_resp = { 'a' => 'foo', 'b' => 123, 'c' => %w[a b c] }
         assert_equal(expected_resp, resp)
 
         # Invocation with block
-        dc.get_multi(%w(a b c d e f)) do |k, v|
-          assert(expected_resp.has_key?(k) && expected_resp[k] == v)
+        dc.get_multi(%w[a b c d e f]) do |k, v|
+          assert(expected_resp.key?(k) && expected_resp[k] == v)
           expected_resp.delete(k)
         end
-        assert expected_resp.empty?
+        assert_empty expected_resp
 
         # Perform a big multi-get with 1000 elements.
         arr = []
@@ -334,16 +343,33 @@ describe 'Dalli' do
       end
     end
 
+    it 'does not corrupt multiget with errors' do
+      memcached_persistent do |dc|
+        dc.close
+        dc.flush
+        dc.set('a', 'av')
+        dc.set('b', 'bv')
+        assert_equal 'av', dc.get('a')
+        assert_equal 'bv', dc.get('b')
+
+        dc.multi do
+          dc.delete('non_existent_key')
+        end
+        assert_equal 'av', dc.get('a')
+        assert_equal 'bv', dc.get('b')
+      end
+    end
+
     it 'support raw incr/decr' do
       memcached_persistent do |client|
         client.flush
 
-        assert op_addset_succeeds(client.set('fakecounter', 0, 0, :raw => true))
+        assert op_addset_succeeds(client.set('fakecounter', 0, 0, raw: true))
         assert_equal 1, client.incr('fakecounter', 1)
         assert_equal 2, client.incr('fakecounter', 1)
         assert_equal 3, client.incr('fakecounter', 1)
         assert_equal 1, client.decr('fakecounter', 2)
-        assert_equal "1", client.get('fakecounter', :raw => true)
+        assert_equal '1', client.get('fakecounter', raw: true)
 
         resp = client.incr('mycounter', 0)
         assert_nil resp
@@ -353,10 +379,10 @@ describe 'Dalli' do
         resp = client.incr('mycounter', 1)
         assert_equal 3, resp
 
-        resp = client.set('rawcounter', 10, 0, :raw => true)
+        resp = client.set('rawcounter', 10, 0, raw: true)
         assert op_cas_succeeds(resp)
 
-        resp = client.get('rawcounter', :raw => true)
+        resp = client.get('rawcounter', raw: true)
         assert_equal '10', resp
 
         resp = client.incr('rawcounter', 1)
@@ -364,7 +390,7 @@ describe 'Dalli' do
       end
     end
 
-    it "support incr/decr operations" do
+    it 'support incr/decr operations' do
       memcached_persistent do |dc|
         dc.flush
 
@@ -380,7 +406,7 @@ describe 'Dalli' do
         current = 10
         100.times do |x|
           resp = dc.incr('counter', 10)
-          assert_equal current + ((x+1)*10), resp
+          assert_equal current + ((x + 1) * 10), resp
         end
 
         resp = dc.decr('10billion', 0, 5, 10)
@@ -415,14 +441,14 @@ describe 'Dalli' do
     it 'support the append and prepend operations' do
       memcached_persistent do |dc|
         dc.flush
-        assert op_addset_succeeds(dc.set('456', 'xyz', 0, :raw => true))
-        assert_equal true, dc.prepend('456', '0')
-        assert_equal true, dc.append('456', '9')
-        assert_equal '0xyz9', dc.get('456', :raw => true)
+        assert op_addset_succeeds(dc.set('456', 'xyz', 0, raw: true))
+        assert dc.prepend('456', '0')
+        assert dc.append('456', '9')
+        assert_equal '0xyz9', dc.get('456', raw: true)
         assert_equal '0xyz9', dc.get('456')
 
-        assert_equal false, dc.append('nonexist', 'abc')
-        assert_equal false, dc.prepend('nonexist', 'abc')
+        refute dc.append('nonexist', 'abc')
+        refute dc.prepend('nonexist', 'abc')
       end
     end
 
@@ -438,17 +464,28 @@ describe 'Dalli' do
 
     it 'support touch operation' do
       memcached_persistent do |dc|
-        begin
-          dc.flush
-          dc.set 'key', 'value'
-          assert_equal true, dc.touch('key', 10)
-          assert_equal true, dc.touch('key')
-          assert_equal 'value', dc.get('key')
-          assert_nil dc.touch('notexist')
-        rescue Dalli::DalliError => e
-          # This will happen when memcached is in lesser version than 1.4.8
-          assert_equal 'Response error 129: Unknown command', e.message
-        end
+        dc.flush
+        dc.set 'key', 'value'
+        assert dc.touch('key', 10)
+        assert dc.touch('key')
+        assert_equal 'value', dc.get('key')
+        assert_nil dc.touch('notexist')
+      rescue Dalli::DalliError => e
+        # This will happen when memcached is in lesser version than 1.4.8
+        assert_equal 'Response error 129: Unknown command', e.message
+      end
+    end
+
+    it 'support gat operation' do
+      memcached_persistent do |dc|
+        dc.flush
+        dc.set 'key', 'value'
+        assert_equal 'value', dc.gat('key', 10)
+        assert_equal 'value', dc.gat('key')
+        assert_nil dc.gat('notexist', 10)
+      rescue Dalli::DalliError => e
+        # This will happen when memcached is in lesser version than 1.4.8
+        assert_equal 'Response error 129: Unknown command', e.message
       end
     end
 
@@ -457,14 +494,14 @@ describe 'Dalli' do
         v = dc.version
         servers = v.keys
         assert(servers.any? do |s|
-          v[s] != nil
-        end, "version failed")
+          !v[s].nil?
+        end, 'version failed')
       end
     end
 
     it 'allow TCP connections to be configured for keepalive' do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :keepalive => true)
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", keepalive: true)
         dc.set(:a, 1)
         ring = dc.send(:ring)
         server = ring.servers.first
@@ -473,11 +510,11 @@ describe 'Dalli' do
         optval = socket.getsockopt(Socket::SOL_SOCKET, Socket::SO_KEEPALIVE)
         optval = optval.unpack 'i'
 
-        assert_equal true, (optval[0] != 0)
+        refute_equal(optval[0], 0)
       end
     end
 
-    it "pass a simple smoke test" do
+    it 'pass a simple smoke test' do
       memcached_persistent do |dc, port|
         resp = dc.flush
         refute_nil resp
@@ -506,23 +543,23 @@ describe 'Dalli' do
         dc.close
         dc = nil
 
-        dc = Dalli::Client.new("localhost:#{port}", :digest_class => ::OpenSSL::Digest::SHA1)
+        dc = Dalli::Client.new("localhost:#{port}", digest_class: ::OpenSSL::Digest::SHA1)
 
-        assert op_addset_succeeds(dc.set('456', 'xyz', 0, :raw => true))
+        assert op_addset_succeeds(dc.set('456', 'xyz', 0, raw: true))
 
         resp = dc.prepend '456', '0'
-        assert_equal true, resp
+        assert resp
 
         resp = dc.append '456', '9'
-        assert_equal true, resp
+        assert resp
 
-        resp = dc.get('456', :raw => true)
+        resp = dc.get('456', raw: true)
         assert_equal '0xyz9', resp
 
         assert op_addset_succeeds(dc.set('456', false))
 
         resp = dc.get('456')
-        assert_equal false, resp
+        refute resp
 
         resp = dc.stats
         assert_equal Hash, resp.class
@@ -531,7 +568,7 @@ describe 'Dalli' do
       end
     end
 
-    it "pass a simple smoke test on unix socket" do
+    it 'pass a simple smoke test on unix socket' do
       memcached_persistent(MemcachedMock::UNIX_SOCKET_PATH) do |dc, path|
         resp = dc.flush
         refute_nil resp
@@ -562,21 +599,21 @@ describe 'Dalli' do
 
         dc = Dalli::Client.new(path)
 
-        assert op_addset_succeeds(dc.set('456', 'xyz', 0, :raw => true))
+        assert op_addset_succeeds(dc.set('456', 'xyz', 0, raw: true))
 
         resp = dc.prepend '456', '0'
-        assert_equal true, resp
+        assert resp
 
         resp = dc.append '456', '9'
-        assert_equal true, resp
+        assert resp
 
-        resp = dc.get('456', :raw => true)
+        resp = dc.get('456', raw: true)
         assert_equal '0xyz9', resp
 
         assert op_addset_succeeds(dc.set('456', false))
 
         resp = dc.get('456')
-        assert_equal false, resp
+        refute resp
 
         resp = dc.stats
         assert_equal Hash, resp.class
@@ -585,7 +622,7 @@ describe 'Dalli' do
       end
     end
 
-    it "support multithreaded access" do
+    it 'support multithreaded access' do
       memcached_persistent do |cache|
         cache.flush
         workers = []
@@ -604,144 +641,115 @@ describe 'Dalli' do
             100.times do
               cache.set('a', 9)
               cache.set('b', 11)
-              inc = cache.incr('cat', 10, 0, 10)
+              cache.incr('cat', 10, 0, 10)
               cache.set('f', 'zzz')
               res = cache.cas('f') do |value|
                 value << 'z'
               end
               refute_nil res
-              assert_equal false, cache.add('a', 11)
-              assert_equal({ 'a' => 9, 'b' => 11 }, cache.get_multi(['a', 'b']))
+              refute cache.add('a', 11)
+              assert_equal({ 'a' => 9, 'b' => 11 }, cache.get_multi(%w[a b]))
               inc = cache.incr('cat', 10)
               assert_equal 0, inc % 5
               cache.decr('cat', 5)
               assert_equal 11, cache.get('b')
 
-              assert_equal %w(a b), cache.get_multi('a', 'b', 'c').keys.sort
-
+              assert_equal %w[a b], cache.get_multi('a', 'b', 'c').keys.sort
             end
           end
         end
 
-        workers.each { |w| w.join }
+        workers.each(&:join)
         cache.flush
       end
     end
 
-    it "handle namespaced keys" do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => 'a')
+    it 'handle namespaced keys' do
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", namespace: 'a')
         dc.set('namespaced', 1)
-        dc2 = Dalli::Client.new("localhost:#{port}", :namespace => 'b')
+        dc2 = Dalli::Client.new("localhost:#{port}", namespace: 'b')
         dc2.set('namespaced', 2)
         assert_equal 1, dc.get('namespaced')
         assert_equal 2, dc2.get('namespaced')
       end
     end
 
-    it "handle nil namespace" do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => nil)
-        assert_equal 'key', dc.send(:validate_key, 'key')
+    it 'handle nil namespace' do
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", namespace: nil)
+        dc.set('key', 1)
+        assert_equal 1, dc.get('key')
       end
     end
 
     it 'truncate cache keys that are too long' do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => 'some:namspace')
-        key = "this cache key is far too long so it must be hashed and truncated and stuff" * 10
-        value = "some value"
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", namespace: 'some:namspace')
+        key = 'this cache key is far too long so it must be hashed and truncated and stuff' * 10
+        value = 'some value'
         assert op_addset_succeeds(dc.set(key, value))
         assert_equal value, dc.get(key)
       end
     end
 
-    it "handle namespaced keys in multi_get" do
-      memcached_persistent do |dc, port|
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => 'a')
+    it 'handle namespaced keys in multi_get' do
+      memcached_persistent do |_, port|
+        dc = Dalli::Client.new("localhost:#{port}", namespace: 'a')
         dc.set('a', 1)
         dc.set('b', 2)
-        assert_equal({'a' => 1, 'b' => 2}, dc.get_multi('a', 'b'))
+        assert_equal({ 'a' => 1, 'b' => 2 }, dc.get_multi('a', 'b'))
       end
     end
 
     it 'handle special Regexp characters in namespace with get_multi' do
-      memcached_persistent do |dc, port|
+      memcached_persistent do |_, port|
         # /(?!)/ is a contradictory PCRE and should never be able to match
-        dc = Dalli::Client.new("localhost:#{port}", :namespace => '(?!)')
+        dc = Dalli::Client.new("localhost:#{port}", namespace: '(?!)')
         dc.set('a', 1)
         dc.set('b', 2)
-        assert_equal({'a' => 1, 'b' => 2}, dc.get_multi('a', 'b'))
+        assert_equal({ 'a' => 1, 'b' => 2 }, dc.get_multi('a', 'b'))
       end
     end
 
-    it "handle application marshalling issues" do
+    it 'handle application marshalling issues' do
       memcached_persistent do |dc|
         with_nil_logger do
-          assert_equal false, dc.set('a', Proc.new { true })
+          assert_raises Dalli::MarshalError do
+            dc.set('a', proc { true })
+          end
         end
       end
     end
 
     describe 'with compression' do
-      it 'allow large values' do
+      it 'does not allow large values' do
         memcached_persistent do |dc|
-          dalli = Dalli::Client.new(dc.instance_variable_get(:@servers), :compress => true)
-
-          value = "0"*1024*1024
+          value = SecureRandom.random_bytes((1024 * 1024) + 30_000)
           with_nil_logger do
-            assert_equal false, dc.set('verylarge', value)
+            assert_raises Dalli::ValueOverMaxSize do
+              dc.set('verylarge', value)
+            end
           end
-          dalli.set('verylarge', value)
         end
       end
 
       it 'allow large values to be set' do
         memcached_persistent do |dc|
-          value = "0"*1024*1024
-          assert dc.set('verylarge', value, nil, :compress => true)
+          value = '0' * 1024 * 1024
+          assert dc.set('verylarge', value, nil, compress: true)
         end
       end
     end
 
-    describe 'in low memory conditions' do
+    it 'supports the with method' do
+      memcached_persistent do |dc|
+        dc.with { |c| c.set('some_key', 'some_value') }
+        assert_equal 'some_value', dc.get('some_key')
 
-      it 'handle error response correctly' do
-        memcached_low_mem_persistent do |dc|
-          failed = false
-          value = "1234567890"*1000
-          1_000.times do |idx|
-            begin
-              assert op_addset_succeeds(dc.set(idx, value))
-            rescue Dalli::DalliError
-              failed = true
-              assert((10..200).include?(idx), "unexpected failure on iteration #{idx}")
-              break
-            end
-          end
-          assert failed, 'did not fail under low memory conditions'
-        end
+        dc.with { |c| c.delete('some_key') }
+        assert_nil dc.get('some_key')
       end
-
-      it 'fit more values with compression' do
-        memcached_low_mem_persistent do |dc, port|
-          dalli = Dalli::Client.new("localhost:#{port}", :compress => true)
-          failed = false
-          value = "1234567890"*100
-          10_000.times do |idx|
-            begin
-              assert op_addset_succeeds(dalli.set(idx, value))
-            rescue Dalli::DalliError
-              failed = true
-              assert((800..2000).include?(idx), "unexpected failure on iteration #{idx}")
-              break
-            end
-          end
-          assert failed, 'did not fail under low memory conditions'
-        end
-      end
-
     end
-
   end
 end
