@@ -1,12 +1,11 @@
 # frozen_string_literal: true
+
 require_relative 'helper'
 
 describe 'Network' do
-
   describe 'assuming a bad network' do
-
     it 'handle no server available' do
-      assert_raises Dalli::RingError, :message => "No server available" do
+      assert_raises Dalli::RingError, message: 'No server available' do
         dc = Dalli::Client.new 'localhost:19333'
         dc.get 'foo'
       end
@@ -14,8 +13,8 @@ describe 'Network' do
 
     describe 'with a fake server' do
       it 'handle connection reset' do
-        memcached_mock(lambda {|sock| sock.close }) do
-          assert_raises Dalli::RingError, :message => "No server available" do
+        memcached_mock(->(sock) { sock.close }) do
+          assert_raises Dalli::RingError, message: 'No server available' do
             dc = Dalli::Client.new('localhost:19123')
             dc.get('abc')
           end
@@ -24,8 +23,8 @@ describe 'Network' do
 
       it 'handle connection reset with unix socket' do
         socket_path = MemcachedMock::UNIX_SOCKET_PATH
-        memcached_mock(lambda {|sock| sock.close }, :start_unix, socket_path) do
-          assert_raises Dalli::RingError, :message => "No server available" do
+        memcached_mock(->(sock) { sock.close }, :start_unix, socket_path) do
+          assert_raises Dalli::RingError, message: 'No server available' do
             dc = Dalli::Client.new(socket_path)
             dc.get('abc')
           end
@@ -33,8 +32,8 @@ describe 'Network' do
       end
 
       it 'handle malformed response' do
-        memcached_mock(lambda {|sock| sock.write('123') }) do
-          assert_raises Dalli::RingError, :message => "No server available" do
+        memcached_mock(->(sock) { sock.write('123') }) do
+          assert_raises Dalli::RingError, message: 'No server available' do
             dc = Dalli::Client.new('localhost:19123')
             dc.get('abc')
           end
@@ -42,8 +41,11 @@ describe 'Network' do
       end
 
       it 'handle connect timeouts' do
-        memcached_mock(lambda {|sock| sleep(0.6); sock.close }, :delayed_start) do
-          assert_raises Dalli::RingError, :message => "No server available" do
+        memcached_mock(lambda { |sock|
+                         sleep(0.6)
+                         sock.close
+                       }, :delayed_start) do
+          assert_raises Dalli::RingError, message: 'No server available' do
             dc = Dalli::Client.new('localhost:19123')
             dc.get('abc')
           end
@@ -51,15 +53,16 @@ describe 'Network' do
       end
 
       it 'handle read timeouts' do
-        memcached_mock(lambda {|sock| sleep(0.6); sock.write('giraffe') }) do
-          assert_raises Dalli::RingError, :message => "No server available" do
+        memcached_mock(lambda { |sock|
+                         sleep(0.6)
+                         sock.write('giraffe')
+                       }) do
+          assert_raises Dalli::RingError, message: 'No server available' do
             dc = Dalli::Client.new('localhost:19123')
             dc.get('abc')
           end
         end
       end
-
     end
-
   end
 end
